@@ -4,13 +4,17 @@
 
 from __future__ import annotations
 
-from typing import Iterable
+import typing
 
 import utf8_locale
 
 from . import test_detect
 
 
+if typing.TYPE_CHECKING:
+    from collections.abc import Iterable
+
+
 def test_utf8_env() -> None:
     """Test get_utf8_env() and, indirectly, detect_utf8_locale()."""
     env = utf8_locale.UTF8Detect().detect().env
