@@ -38,6 +38,7 @@ while getopts 'c:n' o; do
 done
 shift "$((OPTIND - 1))"
 
+# The list of allowed and ignored checks is synced with Rust 1.74.
 set -x
 "$cargo" clippy \
 	--tests \
@@ -54,6 +55,8 @@ set -x
 		-A clippy::std_instead_of_core \
 		-A clippy::implicit_return \
 		-A clippy::question_mark_used \
+		-A clippy::ref_patterns \
+		-A clippy::single_call_fn \
 		-A clippy::self_named_module_files \
 	-W clippy::pedantic \
 	-W clippy::cargo \
