@@ -1,28 +1,7 @@
 #![deny(missing_docs)]
 /*
- * Copyright (c) 2022  Peter Pentchev <roam@ringlet.net>
- * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
+ * SPDX-License-Identifier: BSD-2-Clause
  */
 //! u8loc - run a command in a UTF-8-capable locale
 
@@ -98,7 +77,7 @@ fn parse_args() -> Result<Config> {
                 var @ ("LC_ALL" | "LANGUAGE") => Ok(Config {
                     mode: Mode::QueryEnv(var.to_owned(), preferred),
                 }),
-                other => bail!(format!("Invalid query name '{}' specified", other)),
+                other => bail!(format!("Invalid query name '{other}' specified")),
             }
         }
         None => {
@@ -122,8 +101,8 @@ fn parse_args() -> Result<Config> {
 
 fn show_features() -> Vec<String> {
     vec![format!(
-        "Features: u8loc={} query-env=0.1 query-preferred=0.1 run=0.1",
-        env!("CARGO_PKG_VERSION")
+        "Features: u8loc={ver} query-env=0.1 query-preferred=0.1 run=0.1",
+        ver = env!("CARGO_PKG_VERSION")
     )]
 }
 
@@ -140,11 +119,11 @@ fn get_env(preferred: bool) -> Result<HashMap<String, String>> {
 }
 
 fn query_env(name: &str, preferred: bool) -> Result<Vec<String>> {
-    let env = get_env(preferred)?;
+    let mut env = get_env(preferred)?;
     let value = env
-        .get(name)
-        .with_context(|| format!("Internal error: {:?} should be present in {:?}", name, env))?;
-    Ok(vec![format!("{}", value)])
+        .remove(name)
+        .with_context(|| format!("Internal error: {name:?} should be present in {env:?}"))?;
+    Ok(vec![value])
 }
 
 fn query_list() -> Vec<String> {
@@ -166,13 +145,13 @@ fn run_program(prog: &[String], preferred: bool) -> Result<Vec<String>> {
     let env = get_env(preferred)?;
     let (prog_name, args) = prog.split_first().context("Not even a program name?")?;
     Err(AnyError::new(
-        Command::new(&prog_name)
+        Command::new(prog_name)
             .args(args)
             .env_clear()
             .envs(env)
             .exec(),
     )
-    .context(format!("Could not execute the {} program", prog_name)))
+    .context(format!("Could not execute the {prog_name} program")))
 }
 
 fn run() -> Result<Vec<String>> {
